<?php

namespace App\Entity;

use App\Repository\CollectionRepository;
use DateTimeImmutable;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\DBAL\Types\Types;
use App\RecordStatus;
use Doctrine\Common\Collections\Collection as DoctrineCollection;

#[ORM\Entity(repositoryClass: CollectionRepository::class)]
#[ORM\Table(name: 'collection')]
class Collection
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column(name: 'id')]
    private ?int $id = null;

    #[ORM\Column(name: 'stato')]
    private ?int $status = null;

    #[ORM\Column(name: 'modif')]
    private ?DateTimeImmutable $modifiedAt = null;

    #[ORM\Column(name: 'tit_coll', type: Types::TEXT)]
    private ?string $title = null;

    #[ORM\Column(name: 'data_coll', type: Types::TEXT)]
    private ?string $chronology = null;

    #[ORM\Column(name: 'inizio_coll', type: Types::SMALLINT)]
    private ?int $startDate = null;

    #[ORM\Column(name: 'fine_coll', type: Types::SMALLINT)]
    private ?int $endDate = null;

    #[ORM\Column(name: 'desc_coll', type: Types::TEXT)]
    private ?string $description = null;

    #[ORM\Column(name: 'desc_br_coll', type: Types::TEXT)]
    private ?string $shortDescription = null;

    #[ORM\Column(name: 'id_est_coll', type: Types::TEXT)]
    private ?string $externalIdentifier = null;

    #[ORM\Column(name: 'link_coll', type: Types::TEXT)]
    private ?string $link = null;

    #[ORM\Column(name: 'sogg_coll', type: Types::TEXT)]
    private ?string $subjectHeadings = null;

    #[ORM\Column(name: 'uri_coll', type: Types::TEXT)]
    private ?string $uri = null;

    #[ORM\Column(name: 'resp', length: 100)]
    private ?string $owner = null;

    #[ORM\Column(name: 'note_coll', type: Types::TEXT)]
    private ?string $notes = null;

    #[ORM\Column(length: 100, name: 'editor')]
    private ?string $editor = null;

    #[ORM\Column(length: 100, name: 'creator')]
    private ?string $creator = null;

    // TODO: These are references to vocabs
    #[ORM\Column(name: 'dir_aut_coll')]
    private ?int $authorRights = null;

    #[ORM\Column(name: 'dir_acc_coll')]
    private ?int $accessRights = null;

    #[ORM\Column(name: 'lic_coll')]
    private ?int $license = null;

    #[ORM\JoinTable(name: 'rel_riferimento_collezione')]
    #[ORM\JoinColumn(name: 'Collezione_id_coll', referencedColumnName: 'id')]
    #[ORM\InverseJoinColumn(name: 'Bibliografia_id_bib', referencedColumnName: 'id')]
    #[ORM\ManyToMany(targetEntity: Bibliography::class)]
    private DoctrineCollection $bibliographies;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getStatus(): ?string
    {
        $status = RecordStatus::tryFrom($this->status);
        return $status->toString();
    }

    public function setStatus(int $status): static
    {
        $this->status = $status;

        return $this;
    }

    public function getModifiedAt(): ?DateTimeImmutable
    {
        return $this->modifiedAt;
    }

    public function setModifiedAt(DateTimeImmutable $modifiedAt): static
    {
        $this->modifiedAt = $modifiedAt;

        return $this;
    }

    public function getOwner(): ?string
    {
        return $this->owner;
    }

    public function setOwner(string $owner): static
    {
        $this->owner = $owner;

        return $this;
    }

    public function getEditor(): ?string
    {
        return $this->editor;
    }

    public function setEditor(string $editor): static
    {
        $this->editor = $editor;

        return $this;
    }

    public function getCreator(): ?string
    {
        return $this->creator;
    }

    public function setCreator(string $creator): static
    {
        $this->creator = $creator;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): static
    {
        $this->title = $title;

        return $this;
    }

    public function getChronology(): ?string
    {
        return $this->chronology;
    }

    public function setChronology(string $chronology): static
    {
        $this->chronology = $chronology;

        return $this;
    }

    public function getStartDate(): ?int
    {
        return $this->startDate;
    }

    public function setStartDate(int $startDate): static
    {
        $this->startDate = $startDate;

        return $this;
    }

    public function getEndDate(): ?int
    {
        return $this->endDate;
    }

    public function setEndDate(int $endDate): static
    {
        $this->endDate = $endDate;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(string $description): static
    {
        $this->description = $description;

        return $this;
    }

    public function getShortDescription(): ?string
    {
        return $this->shortDescription;
    }

    public function setShortDescription(string $shortDescription): static
    {
        $this->shortDescription = $shortDescription;

        return $this;
    }

    public function getExternalIdentifier(): ?string
    {
        return $this->externalIdentifier;
    }

    public function setExternalIdentifier(string $externalIdentifier): static
    {
        $this->externalIdentifier = $externalIdentifier;

        return $this;
    }

    public function getLink(): ?string
    {
        return $this->link;
    }

    public function setLink(string $link): static
    {
        $this->link = $link;

        return $this;
    }

    public function getSubjectHeadings(): ?string
    {
        return $this->link;
    }

    public function setSubjectHeadings(string $subjectHeadings): static
    {
        $this->subjectHeadings = $subjectHeadings;

        return $this;
    }

    public function getUri(): ?string
    {
        return $this->uri;
    }

    public function setUri(string $uri): static
    {
        $this->uri = $uri;

        return $this;
    }

    public function getNotes(): ?string
    {
        return $this->notes;
    }

    public function setNotes(string $notes): static
    {
        $this->notes = $notes;

        return $this;
    }

    public function getBibliographies(): ?DoctrineCollection
    {
        return $this->bibliographies;
    }

    public function setBibliographies(DoctrineCollection $bibliographies): static
    {
        $this->bibliographies = $bibliographies;

        return $this;
    }
}
